@@ -14,9 +14,6 @@ type policyAuthorizer struct {
 	// agentRules contain the exact-match agent policies
 	agentRules *radix.Tree
 
-	// identityRules contains the identity exact-match policies
-	identityRules *radix.Tree
-
 	// intentionRules contains the service intention exact-match policies
 	intentionRules *radix.Tree
 
@@ -186,48 +183,6 @@ func (p *policyAuthorizer) loadRules(policy *PolicyRules) error {
 		}
 	}
 
-	// Load the identity policy (exact matches)
-	for _, id := range policy.Identities {
-		if err := insertPolicyIntoRadix(id.Name, id.Policy, &id.EnterpriseRule, p.identityRules, false); err != nil {
-			return err
-		}
-
-		intention := id.Intentions
-		if intention == "" {
-			switch id.Policy {
-			case PolicyRead, PolicyWrite:
-				intention = PolicyRead
-			default:
-				intention = PolicyDeny
-			}
-		}
-
-		if err := insertPolicyIntoRadix(id.Name, intention, &id.EnterpriseRule, p.trafficPermissionsRules, false); err != nil {
-			return err
-		}
-	}
-
-	// Load the identity policy (prefix matches)
-	for _, id := range policy.IdentityPrefixes {
-		if err := insertPolicyIntoRadix(id.Name, id.Policy, &id.EnterpriseRule, p.identityRules, true); err != nil {
-			return err
-		}
-
-		intention := id.Intentions
-		if intention == "" {
-			switch id.Policy {
-			case PolicyRead, PolicyWrite:
-				intention = PolicyRead
-			default:
-				intention = PolicyDeny
-			}
-		}
-
-		if err := insertPolicyIntoRadix(id.Name, intention, &id.EnterpriseRule, p.trafficPermissionsRules, true); err != nil {
-			return err
-		}
-	}
-
 	// Load the key policy (exact matches)
 	for _, kp := range policy.Keys {
 		if err := insertPolicyIntoRadix(kp.Prefix, kp.Policy, &kp.EnterpriseRule, p.keyRules, false); err != nil {
@@ -397,7 +352,6 @@ func newPolicyAuthorizer(policies []*Policy, ent *Config) (*policyAuthorizer, er
 func newPolicyAuthorizerFromRules(rules *PolicyRules, ent *Config) (*policyAuthorizer, error) {
 	p := &policyAuthorizer{
 		agentRules:              radix.New(),
-		identityRules:           radix.New(),
 		intentionRules:          radix.New(),
 		trafficPermissionsRules: radix.New(),
 		keyRules:                radix.New(),
@@ -578,33 +532,6 @@ func (p *policyAuthorizer) EventWrite(name string, _ *AuthorizerContext) Enforce
 	return Default
 }
 
-// IdentityRead checks for permission to read a given workload identity.
-func (p *policyAuthorizer) IdentityRead(name string, _ *AuthorizerContext) EnforcementDecision {
-	if rule, ok := getPolicy(name, p.identityRules); ok {
-		return enforce(rule.access, AccessRead)
-	}
-	return Default
-}
-
-// IdentityReadAll checks for permission to read all workload identities.
-func (p *policyAuthorizer) IdentityReadAll(_ *AuthorizerContext) EnforcementDecision {
-	return p.allAllowed(p.identityRules, AccessRead)
-}
-
-// IdentityWrite checks for permission to create or update a given
-// workload identity.
-func (p *policyAuthorizer) IdentityWrite(name string, _ *AuthorizerContext) EnforcementDecision {
-	if rule, ok := getPolicy(name, p.identityRules); ok {
-		return enforce(rule.access, AccessWrite)
-	}
-	return Default
-}
-
-// IdentityWriteAny checks for write permission on any workload identity.
-func (p *policyAuthorizer) IdentityWriteAny(_ *AuthorizerContext) EnforcementDecision {
-	return p.anyAllowed(p.identityRules, AccessWrite)
-}
-
 // IntentionDefaultAllow returns whether the default behavior when there are
 // no matching intentions is to allow or deny.
 func (p *policyAuthorizer) IntentionDefaultAllow(_ *AuthorizerContext) EnforcementDecision {
