@@ -19,7 +19,6 @@ import (
 	"github.com/hashicorp/consul/internal/resource"
 	"github.com/hashicorp/consul/internal/storage"
 	"github.com/hashicorp/consul/proto-public/pbresource"
-	pbtenancy "github.com/hashicorp/consul/proto-public/pbtenancy/v2beta1"
 )
 
 // Delete deletes a resource.
@@ -200,17 +199,10 @@ func (s *Server) ensureDeleteRequestValid(req *pbresource.DeleteRequest) (*resou
 		return nil, err
 	}
 
-	if err = checkV2Tenancy(s.UseV2Tenancy, req.Id.Type); err != nil {
-		return nil, err
-	}
-
 	if err := validateScopedTenancy(reg.Scope, reg.Type, req.Id.Tenancy, false); err != nil {
 		return nil, err
 	}
 
-	if err := blockBuiltinsDeletion(reg.Type, req.Id); err != nil {
-		return nil, err
-	}
 	return reg, nil
 }
 
@@ -220,12 +212,3 @@ func TombstoneNameFor(deleteId *pbresource.ID) string {
 	// deleteId.Name is just included for easier identification
 	return fmt.Sprintf("tombstone-%v-%v", deleteId.Name, strings.ToLower(deleteId.Uid))
 }
-
-func blockDefaultNamespaceDeletion(rtype *pbresource.Type, id *pbresource.ID) error {
-	if id.Name == resource.DefaultNamespaceName &&
-		id.Tenancy.Partition == resource.DefaultPartitionName &&
-		resource.EqualType(rtype, pbtenancy.NamespaceType) {
-		return status.Errorf(codes.InvalidArgument, "cannot delete default namespace")
-	}
-	return nil
-}
