@@ -11,7 +11,6 @@ import (
 
 	"github.com/hashicorp/consul/api"
 	"github.com/hashicorp/consul/lib"
-	pbmesh "github.com/hashicorp/consul/proto-public/pbmesh/v2beta1"
 )
 
 const (
@@ -181,39 +180,6 @@ type AccessLogsConfig struct {
 	TextFormat string `json:",omitempty" alias:"text_format"`
 }
 
-func (c *AccessLogsConfig) GetEnabled() bool {
-	return c.Enabled
-}
-
-func (c *AccessLogsConfig) GetDisableListenerLogs() bool {
-	return c.DisableListenerLogs
-}
-
-func (c *AccessLogsConfig) GetType() pbmesh.LogSinkType {
-	switch c.Type {
-	case FileLogSinkType:
-		return pbmesh.LogSinkType_LOG_SINK_TYPE_FILE
-	case StdErrLogSinkType:
-		return pbmesh.LogSinkType_LOG_SINK_TYPE_STDERR
-	case StdOutLogSinkType:
-		return pbmesh.LogSinkType_LOG_SINK_TYPE_STDOUT
-	}
-
-	return pbmesh.LogSinkType_LOG_SINK_TYPE_DEFAULT
-}
-
-func (c *AccessLogsConfig) GetPath() string {
-	return c.Path
-}
-
-func (c *AccessLogsConfig) GetJsonFormat() string {
-	return c.JSONFormat
-}
-
-func (c *AccessLogsConfig) GetTextFormat() string {
-	return c.TextFormat
-}
-
 func (c *AccessLogsConfig) IsZero() bool {
 	if c == nil {
 		return true
@@ -839,12 +805,3 @@ func (e *ExposeConfig) Finalize() {
 		}
 	}
 }
-
-type AccessLogs interface {
-	GetEnabled() bool
-	GetDisableListenerLogs() bool
-	GetType() pbmesh.LogSinkType
-	GetPath() string
-	GetJsonFormat() string
-	GetTextFormat() string
-}
