@@ -4,6 +4,7 @@
 package xds
 
 import (
+	"context"
 	"sort"
 	"sync"
 	"testing"
@@ -34,12 +35,9 @@ import (
 	"github.com/hashicorp/consul/agent/connect"
 	"github.com/hashicorp/consul/agent/grpc-external/limiter"
 	"github.com/hashicorp/consul/agent/proxycfg"
-	"github.com/hashicorp/consul/agent/proxycfg-sources/catalog"
 	"github.com/hashicorp/consul/agent/structs"
 	"github.com/hashicorp/consul/agent/xds/response"
 	"github.com/hashicorp/consul/envoyextensions/xdscommon"
-	proxysnapshot "github.com/hashicorp/consul/internal/mesh/proxy-snapshot"
-	"github.com/hashicorp/consul/proto-public/pbresource"
 	"github.com/hashicorp/consul/sdk/testutil"
 )
 
@@ -73,7 +71,7 @@ func newTestSnapshot(
 // testing. It also implements ConnectAuthz to allow control over authorization.
 type testManager struct {
 	sync.Mutex
-	stateChans           map[structs.ServiceID]chan proxysnapshot.ProxySnapshot
+	stateChans           map[structs.ServiceID]chan *proxycfg.ConfigSnapshot
 	drainChans           map[structs.ServiceID]chan struct{}
 	cfgSrcTerminateChans map[structs.ServiceID]chan struct{}
 	cancels              chan structs.ServiceID
@@ -81,7 +79,7 @@ type testManager struct {
 
 func newTestManager(t *testing.T) *testManager {
 	return &testManager{
-		stateChans:           map[structs.ServiceID]chan proxysnapshot.ProxySnapshot{},
+		stateChans:           map[structs.ServiceID]chan *proxycfg.ConfigSnapshot{},
 		drainChans:           map[structs.ServiceID]chan struct{}{},
 		cfgSrcTerminateChans: map[structs.ServiceID]chan struct{}{},
 		cancels:              make(chan structs.ServiceID, 10),
@@ -92,13 +90,13 @@ func newTestManager(t *testing.T) *testManager {
 func (m *testManager) RegisterProxy(t *testing.T, proxyID structs.ServiceID) {
 	m.Lock()
 	defer m.Unlock()
-	m.stateChans[proxyID] = make(chan proxysnapshot.ProxySnapshot, 1)
+	m.stateChans[proxyID] = make(chan *proxycfg.ConfigSnapshot, 1)
 	m.drainChans[proxyID] = make(chan struct{})
 	m.cfgSrcTerminateChans[proxyID] = make(chan struct{})
 }
 
 // Deliver simulates a proxy registration
-func (m *testManager) DeliverConfig(t *testing.T, proxyID structs.ServiceID, cfg proxysnapshot.ProxySnapshot) {
+func (m *testManager) DeliverConfig(t *testing.T, proxyID structs.ServiceID, cfg *proxycfg.ConfigSnapshot) {
 	t.Helper()
 	m.Lock()
 	defer m.Unlock()
@@ -139,10 +137,8 @@ func (m *testManager) CfgSrcTerminate(proxyID structs.ServiceID) {
 }
 
 // Watch implements ConfigManager
-func (m *testManager) Watch(id *pbresource.ID, _ string, _ string) (<-chan proxysnapshot.ProxySnapshot,
-	limiter.SessionTerminatedChan, proxycfg.SrcTerminatedChan, proxysnapshot.CancelFunc, error) {
-	// Create service ID
-	proxyID := structs.NewServiceID(id.Name, catalog.GetEnterpriseMetaFromResourceID(id))
+func (m *testManager) Watch(proxyID structs.ServiceID, _ string, _ string) (<-chan *proxycfg.ConfigSnapshot,
+	limiter.SessionTerminatedChan, proxycfg.SrcTerminatedChan, context.CancelFunc, error) {
 	m.Lock()
 	defer m.Unlock()
 
@@ -798,8 +794,7 @@ func makeTestRoute(t *testing.T, fixtureName string) *envoy_route_v3.RouteConfig
 	switch fixtureName {
 	case "http2:db", "http:db":
 		return &envoy_route_v3.RouteConfiguration{
-			Name:             "db",
-			ValidateClusters: response.MakeBoolValue(true),
+			Name: "db",
 			VirtualHosts: []*envoy_route_v3.VirtualHost{
 				{
 					Name:    "db",
