@@ -1,8 +1,11 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package main
 
 import (
 	"fmt"
-	"io/ioutil"
+	"io"
 	"log"
 	"os"
 
@@ -11,25 +14,20 @@ import (
 	"github.com/hashicorp/consul/command"
 	"github.com/hashicorp/consul/command/cli"
 	"github.com/hashicorp/consul/command/version"
-	"github.com/hashicorp/consul/lib"
 	_ "github.com/hashicorp/consul/service_os"
 )
 
-func init() {
-	lib.SeedMathRand()
-}
-
 func main() {
 	os.Exit(realMain())
 }
 
 func realMain() int {
-	log.SetOutput(ioutil.Discard)
+	log.SetOutput(io.Discard)
 
 	ui := &cli.BasicUI{
 		BasicUi: mcli.BasicUi{Writer: os.Stdout, ErrorWriter: os.Stderr},
 	}
-	cmds := command.CommandsFromRegistry(ui)
+	cmds := command.RegisteredCommands(ui)
 	var names []string
 	for c := range cmds {
 		names = append(names, c)
